Module sys

Module sys 

Contains the original C Types, functions, enums, and constants

Modules

enums
function_table
guids
result
structs
version
Contains the nvenc version numbers, encoded as they are in C, for the version this crate was built against